@@ -1,9 +1,9 @@
+from _pytest.main import EXIT_NOTESTSCOLLECTED
 import pytest
 
 def test_simple_unittest(testdir):
     testpath = testdir.makepyfile("""
         import unittest
-        pytest_plugins = "pytest_unittest"
         class MyTestCase(unittest.TestCase):
             def testpassing(self):
                 self.assertEquals('foo', 'foo')
@@ -17,7 +17,6 @@ def test_simple_unittest(testdir):
 def test_runTest_method(testdir):
     testdir.makepyfile("""
         import unittest
-        pytest_plugins = "pytest_unittest"
         class MyTestCaseWithRunTest(unittest.TestCase):
             def runTest(self):
                 self.assertEquals('foo', 'foo')
@@ -43,7 +42,7 @@ def test_isclasscheck_issue53(testdir):
         E = _E()
     """)
     result = testdir.runpytest(testpath)
-    assert result.ret == 0
+    assert result.ret == EXIT_NOTESTSCOLLECTED
 
 def test_setup(testdir):
     testpath = testdir.makepyfile("""
@@ -574,7 +573,7 @@ def test_unorderable_types(testdir):
     """)
     result = testdir.runpytest()
     assert "TypeError" not in result.stdout.str()
-    assert result.ret == 0
+    assert result.ret == EXIT_NOTESTSCOLLECTED
 
 def test_unittest_typerror_traceback(testdir):
     testdir.makepyfile("""
